<div class="card m-0 border-info">
    <div class="card-header text-center">
        EXAMPLE: copy the contest link
    </div>
    <div class="card-body text-start">
        <h6 class="mt-4">Contest Link</h6>
        <div class="input-group mb-3">
            <input type="text" value="https://tinycontestwinners.com/signup?name=O611345sPe5zwtlaDRc1kvLo" class="form-control form-control-sm" id="example-link" readonly>
            <button class="btn btn-outline-secondary" type="button" id="example-copy" disabled>copy</button>
        </div>
    </div>
</div>
