{% extends "base.html" %}

{% block content %}
<h3>Privacy Policy</h3>
<p><i>Last modified: Apr 4th, 2023</i></p>

<p>At Tiny Contest Winners, privacy is taken very seriously.
This policy outlines the measures taken by Tiny Contest Winners to protect the
privacy of its users.</p>


<h3>1. Service description</h3>
<p>Tiny Contest Winners is a free web based service that allows users to create
ephemeral contests, whose winners are picked at random.


<h3>2. How the contests are processed</h3>
<p>The contest-signup link is generated in the contest creators browser.
The link is thus in the creator's possesion only, and they determine who
receives the contest link.</p>

<p>Once a contest has expired, the winners are picked at random. After
notifying the contest owner by email who the winners are, all information about
the contest is removed completely from the database.</p>

<p>After a contest is deleted from our database, there is absolutely
no way to recover it again.</p>

<p>Tiny Contest Winners sysadmin team will do as much as possible to
protect the site against unauthorized access, modification or
destruction of the data.</p>


<h3>3. Disclaimer</h3>
<p>When a person clicks the Tiny Contest Winners link, Tiny Contest Winners
declines any responsibility related to the contest's content.</p>


<h3>4. Disclosure of Data to Third Party</h3>
<p>Tiny Contest Winners does not share nor sell any information to others,
nor use it in any way not mentioned in this Privacy Policy.</p>


<h3>5. Use of cookies</h3>
<p>The Tiny Contest Winners website does not use cookies</p>


<h3>6. Validity of this Privacy Policy</h3>
<p>Please note that this Privacy Policy may change from time to time.
We expect most changes to be minor. Regardless, we will post any Policy
changes on this page, and if the changes are significant,
we will provide a more prominent notice such as a message on the home page.
Each version of this Policy will be identified at the top of the page by
its effective date.</p>


<h3>7. Contact information</h3>
<p>If you have any questions about this Privacy Policy or other concerns
regarding privacy issues, please send us an e-mail
at support@tinycontestwinners.com.
</p>

{% endblock %}
