<!DOCTYPE html>

<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <title>Tiny Contest Winners - Create fun, ephemeral, contests and raffles</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.4/font/bootstrap-icons.css">
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM" crossorigin="anonymous"></script>
    </head>
    <body>
        <div class="container-md mt-4 text-center" style="margin-bottom: 8.0rem;">
            <div class="card">
                <div class="card-body">
                    <h3>404</h3>
                    <p>
                        <i class="fs-5 bi-emoji-frown"></i>
                        <br>
                        That page could not be found
                    </p>
                    <a href="{{ url_for('contest.index') }}">home</a>
                </div>
            </div>
        </div>
        <footer class="footer fixed-bottom" style="background: #EEE;">
            <ul class="nav justify-content-center">
                <li class=nav-item><a href="{{ url_for('contest.index') }}" class="nav-link px-2 text-muted">&copy; 2022 Tiny Contest Winners</a></li>
                <li class="nav-item"><a href="{{ url_for('contest.privacy') }}" class="nav-link px-2 text-muted">Privacy</a></li>
                <li class="nav-item"><a href="{{ url_for('contest.about') }}" class="nav-link px-2 text-muted">About</a></li>
            </ul>
        </footer>
  </body>
</html>
