<div class="card m-0 border-info">
    <div class="card-header text-center">
        EXAMPLE: send contest to the community
    </div>
    <div class="card-body text-start" id="example-conversation">

    </div>
</div>
